@@ -21,7 +21,7 @@
 
 /*! \file m_sjoin.c
  * \brief Includes required functions for processing the SJOIN command.
- * \version $Id: m_sjoin.c 7007 2016-01-01 00:09:08Z michael $
+ * \version $Id: m_sjoin.c 7356 2016-02-22 18:59:30Z michael $
  */
 
 #include "stdinc.h"
@@ -71,9 +71,9 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
   struct Client  *target_p = NULL;
-  time_t         newts;
-  time_t         oldts;
-  time_t         tstosend;
+  uintmax_t newts;
+  uintmax_t oldts;
+  uintmax_t tstosend;
   struct Mode mode, *oldmode;
   int            args = 0;
   char           keep_our_modes = 1;
@@ -109,7 +109,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   modebuf[0] = '\0';
   mbuf = modebuf;
   pargs = 0;
-  newts = strtoimax(parv[1], NULL, 10);
+  newts = strtoumax(parv[1], NULL, 10);
 
   mode.mode = 0;
   mode.limit = 0;
@@ -585,7 +585,7 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
   if (mode->limit && oldmode->limit != mode->limit)
   {
     *mbuf++ = 'l';
-    len = sprintf(pbuf, "%d ", mode->limit);
+    len = sprintf(pbuf, "%u ", mode->limit);
     pbuf += len;
     pargs++;
   }
@@ -773,7 +773,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 7007 $",
+  .version = "$Revision: 7356 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
